@@ -1,10 +1,22 @@
 import unittest
 from postcodepy import postcodepy
 
-access_key="WY7vmPZN9e0p1W4qdaYKbHyDfL7J94YgbIp2z944oZE"
-access_secret="c57Og9t8Lb14A8mHru9BEHwzdoyF7cBqb3xV5rQB4aC"
+import os, sys
+
+access_key = None
+access_secret = None
 
 class TestUM(unittest.TestCase):
+    def setUp(self):
+      global access_key
+      access_key = os.getenv("ACCESS_KEY")
+      global access_secret
+      access_secret = os.getenv("ACCESS_SECRET")
+      if not (access_key and access_secret ):
+        print "provide an access key and secret via environment:"
+        print "export ACCESS_KEY=..."
+        print "export ACCESS_SECRET=..."
+        self.skipTest(self)
 
     def test_Postcode(self):
       """ test retrieval of data
@@ -32,3 +44,7 @@ class TestUM(unittest.TestCase):
       """
       self.assertRaises( postcodepy.PostcodeError,  lambda: postcodepy.API( environment='live', access_secret=access_secret))
 
+if __name__ == "__main__":
+
+  unittest.main()
+
